@@ -20,8 +20,11 @@
 use APP\core\Application;
 
 $requestPath = Application::get()->getRequest()->getRequestPath();
+
 if (strpos($requestPath, '/files')) {
-    return new \PKP\API\v1\submissions\PKPSubmissionFileHandler();
+    return new \PKP\handler\APIHandler(new \PKP\API\v1\submissions\PKPSubmissionFileController());
+} elseif (strpos($requestPath, '/suggestions')) {
+    return new \PKP\handler\APIHandler(new PKP\API\v1\reviewers\suggestions\ReviewerSuggestionController());
 } else {
-    return new \PKP\API\v1\submissions\PKPSubmissionHandler();
+    return new \PKP\handler\APIHandler(new \APP\API\v1\submissions\SubmissionController());
 }
