@@ -37,11 +37,22 @@ class Config
      * ]
      */
     public const SENSITIVE_DATA = [
+        'general' => [
+            'app_key',
+        ],
         'database' => [
             'password',
         ],
         'email' => [
             'smtp_password',
+            'smtp_username',
+        ],
+        'security' => [
+            'api_key_secret',
+            'salt',
+        ],
+        'captcha' => [
+            'recaptcha_private_key',
         ],
     ];
 
@@ -105,6 +116,14 @@ class Config
         return $configData;
     }
 
+    /**
+     * Reset the config data in registry
+     */
+    public static function resetData()
+    {
+        Registry::set('configData', static::reloadData());
+    }
+
     /**
      * Set the path to the configuration file.
      *
