@@ -110,7 +110,7 @@ abstract class PKPStatsEditorialQueryBuilder
             $q->where('s.date_submitted', '<=', $this->dateEnd);
         }
 
-        return $q->count();
+        return $q->getCountForPagination();
     }
 
     /**
@@ -184,7 +184,7 @@ abstract class PKPStatsEditorialQueryBuilder
     {
         return $this->_getObject()
             ->whereIn('s.status', (array) $status)
-            ->count();
+            ->getCountForPagination();
     }
 
     /**
@@ -199,7 +199,7 @@ abstract class PKPStatsEditorialQueryBuilder
         return $this->_getObject()
             ->where('s.status', '=', PKPSubmission::STATUS_QUEUED)
             ->whereIn('s.stage_id', $stages)
-            ->count();
+            ->getCountForPagination();
     }
 
     /**
@@ -234,7 +234,7 @@ abstract class PKPStatsEditorialQueryBuilder
             }
         }
 
-        return $q->count();
+        return $q->getCountForPagination();
     }
 
     /**
@@ -381,20 +381,22 @@ abstract class PKPStatsEditorialQueryBuilder
      *
      * The dateStart and dateEnd filters are not handled here because
      * the dates must be applied differently for each set of data.
+     *
+     * @hook Stats::editorial::queryObject [[&$q, $this]]
      */
     protected function _getObject(): Builder
     {
         $q = $this->_getBaseQuery();
 
         // Exclude incomplete submissions
-        $q->where('s.submission_progress', '=', 0);
+        $q->where('s.submission_progress', '=', '');
 
         // Exclude submissions when the date_submitted is later
         // than the first date_published. This prevents imported
         // submissions from being counted in editorial stats.
         $q->where(
             fn (Builder $q) => $q->whereNull('pi.date_published')
-                ->orWhere('s.date_submitted', '<=', DB::raw('pi.date_published'))
+                ->orWhere(DB::raw('CAST(s.date_submitted AS DATE)'), '<=', DB::raw('pi.date_published'))
         );
 
         Hook::call('Stats::editorial::queryObject', [&$q, $this]);
@@ -455,10 +457,10 @@ abstract class PKPStatsEditorialQueryBuilder
     public function countImported()
     {
         return $this->_getBaseQuery()
-            ->whereColumn('s.date_submitted', '>', 'pi.date_published')
+            ->where(DB::raw('CAST(s.date_submitted AS DATE)'), '>', DB::raw('pi.date_published'))
             ->when($this->dateStart, fn (Builder $q) => $q->where('s.date_submitted', '>=', $this->dateStart))
             ->when($this->dateEnd, fn (Builder $q) => $q->where('s.date_submitted', '<=', $this->dateEnd))
-            ->count();
+            ->getCountForPagination();
     }
 
     /**
@@ -470,10 +472,10 @@ abstract class PKPStatsEditorialQueryBuilder
     public function countInProgress()
     {
         return $this->_getBaseQuery()
-            ->where('s.submission_progress', '<>', 0)
+            ->where('s.submission_progress', '<>', '')
             ->when($this->dateStart, fn (Builder $q) => $q->where('s.date_submitted', '>=', $this->dateStart))
             ->when($this->dateEnd, fn (Builder $q) => $q->where('s.date_submitted', '<=', $this->dateEnd))
-            ->count();
+            ->getCountForPagination();
     }
 
     /**
@@ -491,11 +493,9 @@ abstract class PKPStatsEditorialQueryBuilder
      */
     private function _dateDiff(string $leftDate, string $rightDate)
     {
-        switch (Config::getVar('database', 'driver')) {
-            case 'mysql':
-            case 'mysqli':
-                return 'DATEDIFF(' . $leftDate . ',' . $rightDate . ')';
-        }
-        return "DATE_PART('day', " . $leftDate . ' - ' . $rightDate . ')';
+        return match (Config::getVar('database', 'driver')) {
+            'mysql', 'mysqli', 'mariadb' => 'DATEDIFF(' . $leftDate . ',' . $rightDate . ')',
+            default => "DATE_PART('day', " . $leftDate . ' - ' . $rightDate . ')'
+        };
     }
 }
