@@ -8,13 +8,9 @@
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup plugins_oaiMetadataFormats
+ *
  * @brief Wrapper for the OAI DC format plugin.
  *
  */
 
-require_once('OAIMetadataFormatPlugin_DC.inc.php');
-require_once('OAIMetadataFormat_DC.inc.php');
-
-return new OAIMetadataFormatPlugin_DC();
-
-
+return new \APP\plugins\oaiMetadataFormats\dc\OAIMetadataFormatPlugin_DC();
